# Timesheet Excel Editor

An application that allows you to edit excel timesheet.

## Requirements

In order to install wxPython, you need to install the Gtk dependency. Can do it with this command:

```shell
sudo apt-get install libgtk-3-dev
```

Or, for make the process faster, you can install the wxPython wheel for your system yourself from
[this](https://extras.wxpython.org/wxPython4/extras/linux/gtk3/) link.

For example, for Ubuntu 20.04, you can download 
[this](https://extras.wxpython.org/wxPython4/extras/linux/gtk3/ubuntu-20.04/wxPython-4.1.1-cp38-cp38-linux_x86_64.whl).

## Installation

You can install the package from [PyPI](https://pypi.org/project/TimesheetExcelEditor/):

```shell
pip install TimesheetExcelEditor 
```
